@@ -91,6 +91,7 @@ extern "C" SEXP bootstrapValidationResCpp(SEXP _fraction,SEXP _loops,SEXP _dataf
 		std::vector<double>testPrediction;
 		std::vector<double>testResiduals;
 		vec testSampledRMSE(loops);
+		vec varoutcome(loops);
 		mat bcoef(loops,dataframe.n_cols); 	  
 		mat bmeans(loops,dataframe.n_cols); 
 		mat	NeRi(loops,n_var2); 
@@ -111,7 +112,7 @@ extern "C" SEXP bootstrapValidationResCpp(SEXP _fraction,SEXP _loops,SEXP _dataf
 //		double omin=min(Outcome);
 //		double range = max(Outcome)-omin;
 
-#pragma omp parallel for schedule(dynamic) ordered shared(lastInserted,trainResiduals,testOutcome,testPrediction,testResiduals,trainSampledRMSE,testSampledRMSE,bcoef,bmeans,NeRi,tpvalue,wpvalue,spvalue,Fpvalue,test_tpvalue,test_wpvalue,test_spvalue,test_Fpvalue)
+#pragma omp parallel for schedule(dynamic) ordered shared(lastInserted,trainResiduals,testOutcome,testPrediction,testResiduals,trainSampledRMSE,testSampledRMSE,bcoef,bmeans,NeRi,tpvalue,wpvalue,spvalue,Fpvalue,test_tpvalue,test_wpvalue,test_spvalue,test_Fpvalue,varoutcome)
 		for (int doOver=0;doOver<loops;doOver++)
 		{ 
 			uvec eqindex = equSamples(ttcasesample);
@@ -122,9 +123,10 @@ extern "C" SEXP bootstrapValidationResCpp(SEXP _fraction,SEXP _loops,SEXP _dataf
 			mat bestTrainingSample;
 			uvec ntestSample;
 			uvec samCases;
-			unsigned int mintestSample = 4;
+			unsigned int cycle = 0;
+			unsigned int mintestSample = 2;
 			do
-			{
+			{ 
 				samCases = randi<uvec>(totSamples, distr_param(0,sizecases-1));
 				vec auxcasesample=zeros<vec>(sizecases);
 				for (int i=0;i<totSamples;i++)
@@ -132,10 +134,16 @@ extern "C" SEXP bootstrapValidationResCpp(SEXP _fraction,SEXP _loops,SEXP _dataf
 					auxcasesample[samCases[i]]=1;
 				}
 				ntestSample=find(auxcasesample==0);
+				++cycle;
+				if (cycle > 5) 
+				{
+					ntestSample=find(auxcasesample==1); //same as train if no enough data sample
+				}
 			} while (ntestSample.n_elem<mintestSample);	
 
 			trainingSample = tcasesample.rows(samCases);
 			bestTrainingSample = bestSample.rows(samCases);	
+			varoutcome(doOver) = var(tcasesample.col(1));
 			vec trainmodel = modelFittingFunc(trainingSample.cols(0,1),trainingSample.cols(2,trainingSample.n_cols-1),type);
 			if (!trainmodel.has_nan())
 			{
@@ -201,6 +209,10 @@ extern "C" SEXP bootstrapValidationResCpp(SEXP _fraction,SEXP _loops,SEXP _dataf
 		
 			if ((3*lastInserted)<loops) Rcout<<"Warning: only "<<lastInserted<<" samples of "<<loops<<" were inserted\n";
 		}
+		double totsd =0;
+		for (int doOver=0;doOver<loops;doOver++) totsd += varoutcome(doOver);
+		totsd = std::sqrt(totsd/loops);
+		
 //		Rcout<<" First t-pvalue: "<<tpvalue(0,0)<<"\n";
 
 	 	rowvec bootmodel = mean (bcoef);
@@ -236,7 +248,9 @@ extern "C" SEXP bootstrapValidationResCpp(SEXP _fraction,SEXP _loops,SEXP _dataf
 						Rcpp::Named("testSampledRMSE")=Rcpp::wrap(testSampledRMSE),\
 						Rcpp::Named("startRMSE")=Rcpp::wrap(startRMSE), \
 						Rcpp::Named("bootRMSE")=Rcpp::wrap(bootRMSE), \
-						Rcpp::Named("trainResiduals")=Rcpp::wrap(trainResiduals) 
+						Rcpp::Named("trainResiduals")=Rcpp::wrap(trainResiduals), \
+						Rcpp::Named("OutcomeSD")=Rcpp::wrap(totsd)
+						
 					);
 						
 
@@ -266,6 +280,8 @@ std::string residualFowardSelection(const unsigned int size,const int totSamples
 	unsigned int sizecases = dataframe.n_rows;
 //	unsigned int featuresize=std::max((unsigned int)dataframe.n_cols-1,(unsigned int)ovnames.size());
 
+//	Rcout <<" Hello \n";	
+
 	arma::mat mysample = dataframe;
 	arma::mat myTestsample = dataframe;
 
@@ -296,14 +312,16 @@ std::string residualFowardSelection(const unsigned int size,const int totSamples
 	for(unsigned  int j=0;j<covari.size();j++)
 		for(unsigned int i=0;i<vnames.size();i++)
 			if (covari[j]==vnames[i]) vnames[i]=inname;
+	unsigned int cycle = 0;
 	if (loops > 1)
 	{
-		unsigned int mitestsize=4;
+		unsigned int mitestsize=2;
 		uvec notinserted;
 		uvec samCases;
 		vec auxcasesample;
 		double omin=min(randOutput);
 		double range=max(randOutput)-omin;
+		cycle = 0;
 		do
 		{
 			samCases= randi<uvec>(totSamples, distr_param(0,sizecases-1));
@@ -313,6 +331,8 @@ std::string residualFowardSelection(const unsigned int size,const int totSamples
 				auxcasesample[samCases(i)]=1;
 			}
 			notinserted = find(auxcasesample==0);
+			++cycle;
+			if (cycle > 5) return frm1;	 //exit no models
 		}	
 		while (notinserted.n_elem<mitestsize);
 		mysample = dataframe.rows(samCases);
@@ -405,7 +425,6 @@ std::string residualFowardSelection(const unsigned int size,const int totSamples
 	mat mysampleMat;
 	vec testResiduals;
 	vec trainResiduals;
-	int cycle=0;
 	double error=1.0;
 	double tol=1.0e-6;
 	unsigned int maximumNoselectedCount=25;
@@ -419,7 +438,8 @@ std::string residualFowardSelection(const unsigned int size,const int totSamples
 			nideex[j]=lockup[vnames[j]];
 		}
 	}
-	while ((changes>0)&&(error>tol))
+	cycle=0;
+	while ((changes>0)&&(error>tol)&&(cycle < 2*featuresize))
 	{
 		changes = 0;
 	  	minpiri = pthr2;
